function [fwhm, omega1D, S1D] = calcFWHMfromFFCF(Delta, tau, Gamma)
%{
Calculate FWHM from FFCF parameters
    Inputs;
        Delta in cm^-1, row vector of 4 values
        tau in ps, row vector of 3 values
        Gamma in cm^-1

    Outputs:
        fwhm:   fwhm of absorption lineshape in cm^-1
        omega:  frequency axis in cm^-1
        S1:     normalized absorption spectrum 
%}
    %validate number of parameters
    if length(tau) ~= 3
        error('Wrong number of tau parameters entered.');
    end
    if length(Delta) ~= 4
        error('Wrong number of Delta parameters entered.');
    end
    
    %replace taus with zero value to nonzero so it doesn't crash
    for i = 1:3
        if tau(i) <= 0
            tau(i) = 1;
        end
    end

    c = 2.99792458e-2; %speed of light in cm/ps

    Delta_radps = Delta*2*pi*c;                 %Convert Delta to rad/ps
    T2 = 1/(Gamma*pi*c);                        %Convert Gamma to T_2
    g1 = @(t) g_exact(t, Delta_radps, [tau Inf], T2); %Calculate lineshape function
    
    taumax = 2/sqrt(sum(Delta_radps.^2)+1/T2^2); %estimate maximum t value for FID (from Gaussian approx.)
    step = .01*taumax;                          
    while exp(-g1(taumax)) > .0005   %Find maximum t value for FID
        taumax = taumax + step;
    end
    ndt = 100;
    dtau = taumax/ndt;              %Discretize t

    voigt_width = Gamma/2 + sqrt((Gamma/2)^2+2.355*sum(Delta.^2)); %Calculate max possible FWHM using Voigt shape
    peak_center = 0;
    peak_from = peak_center-voigt_width*2;
    peak_to = peak_center+voigt_width*2;
    range_omega1 = [peak_from, peak_to]; %Calculate omega1 range based on Voigt width

    t1 = 0:dtau:taumax;  %Calculate t for FID
    zero_pad = 2;        %FID zero padding factor for FFT
    
    t1_num = length(t1);
    R1 = zeros(t1_num, 1);
    for i = 1:t1_num
       R1(i) = exp(-g1(t1(i))); % Linear response function 
    end
    [ S1, omega ] = Gen_1D_Spec( R1, t1, zero_pad ); %Fourier transform R1
    omega_shifted = omega + peak_center;
    %trim S1 and omega to range_omega1
    trimindex = min(range_omega1) <= omega_shifted & omega_shifted <= max(range_omega1);
    omega1D = omega_shifted(trimindex);
    S1D = real(S1(trimindex));

    fwhm = calc_fwhm_mod(omega1D,S1D,peak_center); %Calculate FWHM of line shape

end